## Version 0.12.10

This release includes critical bug fixes to enhance the functionality and stability of the document store features.

### New Features

- No new features were added in this version.

### Bug Fixes

- Fixed an issue in LanceDBDocStore where setting `use_tantivy` to `False` prevents a `ValueError` during FTS index creation by ensuring `field_names` is a string. (89a6869) (Eric Ma)
- Corrected a `ValueError` in `create_fts_index` by changing the `field_names` argument from a list to a string when `use_tantivy` is set to `False`. (4ad2dab) (Eric Ma)

### Deprecations

- No deprecations in this version.
